#
# spec file for package soundtouch
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           soundtouch
Url:            http://www.surina.net/soundtouch
Summary:        Audio Processing Library
License:        LGPL-2.1+
Group:          Productivity/Multimedia/Sound/Editors and Convertors
Version:        1.8.0
Release:        lp151.5.2
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkg-config
Source:         http://www.surina.net/soundtouch/%{name}-%{version}.tar.gz
# From http://ftp.debian.org/debian/pool/main/s/soundtouch/soundtouch_1.6.0-3.debian.tar.gz
Source1:        soundstretch.1
Source99:       baselibs.conf
Patch0:         soundtouch-fix-buffer-overflow.patch
# PATCH-FIX-UPSTREAM soundtouch-throw-exception.patch https://gitlab.com/soundtouch/soundtouch/commit/a1c400eb2cff849c0e5f9d6916d69ffea3ad2c85 -- Fix issue CVE-2018-17096: Replace assert with runtime exception
Patch1:         soundtouch-throw-exception.patch
# PATCH-FIX-UPSTREAM soundtouch-avoid-assert.patch https://gitlab.com/soundtouch/soundtouch/commit/59129fa33d183e66f0a276795a59aa61a3e2fa06 -- Eliminate assert condition
Patch2:         soundtouch-avoid-assert.patch
# PATCH-FIX-UPSTREAM soundtouch-round-buffer.patch https://gitlab.com/soundtouch/soundtouch/commit/09e04252dde9ef02a7d254315b13089996afe302 and https://gitlab.com/soundtouch/soundtouch/commit/7f594f8b7d10bbc16a4a31de8ec5a279af9c7378 -- Fix CVE-2018-17097 by rounding working buffer size
Patch3:         soundtouch-round-buffer.patch
# PATCH-FIX-UPSTREAM soundtouch-adjust-bounds.patch https://gitlab.com/soundtouch/soundtouch/commit/244fbeac24211a967cdcd523d46af5d9d3e83b57 -- Fix possible reading past end of array
Patch4:         soundtouch-adjust-bounds.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
SoundTouch is an open source audio processing library that allows
changing the sound tempo, pitch and playback rate parameters
independently from each other.
*Easy-to-use implementation of time-stretch, pitch-shift and sample
 rate transposing routines.
*High-performance object-oriented C++ implementation.
*Clear and easy-to-use programming interface via a single C++ class.
*Supported audio data format : 16Bit integer or 32bit floating point
 PCM mono/stereo
*Capable of real-time audio stream processing:
 input/output latency max. ~ 100 ms.
 Processing 44.1kHz/16bit stereo sound in realtime requires a 133 Mhz
 Intel Pentium processor or better.
*Additional assembler-level and Intel-MMX instruction set optimizations
 for Intel x86 compatible processors, offering several times increase
 in the processing performance.

%package -n libSoundTouch0
Summary:        Audio Processing Library
Group:          System/Libraries

%description -n libSoundTouch0
SoundTouch is an open source audio processing library that allows
changing the sound tempo, pitch and playback rate parameters
independently from each other.

%package devel
Summary:        Audio Processing Library
Group:          Development/Languages/C and C++
Requires:       libSoundTouch0 = %{version}
Requires:       glibc-devel

%description devel
SoundTouch is an open-source audio processing library that allows
changing the sound tempo, pitch and playback rate parameters
independently from each other.

%prep
%setup -q -n %{name}
tr -d '\r' <README.html >README.html~
touch -r README.html README.html~
mv README.html~ README.html
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1

%build
./bootstrap
%configure\
	--enable-shared\
	--disable-static
make %{?_smp_mflags} pkgdocdir=%{_docdir}/%{name}

%install
%makeinstall pkgdocdir=%{_docdir}/%{name}
rm -f $RPM_BUILD_ROOT%{_libdir}/lib*.la
# Add man page for soundstretch generated by help2man
mkdir -p %{buildroot}%{_mandir}/man1
cp %{S:1} %{buildroot}%{_mandir}/man1

%post -n libSoundTouch0 -p /sbin/ldconfig

%postun -n libSoundTouch0 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc %{_docdir}/%{name}
%{_bindir}/*
%{_mandir}/man1/*

%files -n libSoundTouch0
%defattr(-,root,root)
%{_libdir}/libSoundTouch.so.0*

%files devel
%defattr(-,root,root)
%{_datadir}/aclocal/*.m4
%{_includedir}/soundtouch
%{_libdir}/pkgconfig/*.pc
%{_libdir}/*.so

%changelog
* Mon Jan  7 2019 Marketa Calabkova <mcalabkova@suse.com>
- Fixed bugs:
  * CVE-2018-17098 (bsc#1108632) -- remote denial of service
- Added patch soundtouch-adjust-bounds.patch
* Mon Dec 10 2018 Marketa Calabkova <mcalabkova@suse.com>
- Fixed bugs:
  * CVE-2018-17098 (bsc#1108632) -- remote denial of service
  * CVE-2018-17097 (bsc#1108631) -- remote denial of service (double free)
- Modified patch soundtouch-round-buffer.patch by aplying upstream
  commit 7f594f
* Mon Oct 29 2018 Marketa Calabkova <mcalabkova@suse.com>
- Fixed bugs:
  * CVE-2018-17098 (bsc#1108632) -- remote denial of service
  * CVE-2018-17097 (bsc#1108631) -- remote denial of service (double free)
  * CVE-2018-17096 (bsc#1108630) -- remote denial of service
    in BPMDetect.cpp
- Added patches:
  * soundtouch-throw-exception.patch -- fixes bsc#1108630
  * soundtouch-avoid-assert.patch
  * soundtouch-round-buffer.patch -- fixes bsc#1108631 and bsc#1108632
- Renamed fix-buffer-overflow.patch to soundtouch-fix-buffer-overflow.patch
* Thu Sep  6 2018 Marketa Calabkova <mcalabkova@suse.com>
- bsc #1103676: CVE-2018-1000223: soundtouch: Heap-based buffer overflow
  added patch fix-buffer-overflow.patch
* Sun Apr  5 2015 p.drouand@gmail.com
- Add baselibs.conf in sources list; fix for Factory
* Wed Mar 25 2015 p.drouand@gmail.com
- Update to version 1.8.0
  * Added support for multi-channel audio processing
  * Added support for cubic and shannon interpolation for rate and
    pitch shift effects besides the original linear interpolation,
    to reduce aliasing at high frequencies due to interpolation.
    Cubic interpolation is used as default for floating point processing,
    and linear interpolation for integer processing.
  * Fixed bug in anti-alias filtering that limited stop-band attenuation
    to -10 dB instead of <-50dB, and increased filter length from 32 to 64
    taps to further reduce aliasing due to frequency folding.
  * Performance improvements in cross-correlation algorithm
  * Other bug and compatibility fixes
- Remove obsolete AUTHORS and %%clean sections
* Fri Jan 25 2013 sbrabec@suse.cz
- Update to version 1.7.1:
  * Added files for Android compilation
  * Sound quality improvements
  * Improved flush() to adjust output sound stream duration to
    match better with ideal duration
  * Rewrote x86 cpu feature check to resolve compatibility problems
  * Configure script automatically checks if CPU supports mmx & sse
    compatibility for GNU platform, and the script support now
    "--enable-x86-optimizations" switch to allow disabling
    x86-specific optimizations.
  * Revised #define conditions for 32bit/64bit compatibility
  * gnu autoconf/automake script compatibility fixes
  * Tuned beat-per-minute detection algorithm
- Updated man page from Debian unstable.
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Wed Aug 10 2011 ampsaltis@gmail.com
- New upstream version 1.6.0.
- Changes:
  * Added automatic cutoff threshold adaptation to beat detection
    routine to better adapt BPM calculation to different types of
    music
  * Retired 3DNow! optimization support as 3DNow! is nowadays
    obsoleted and assembler code is nuisance to maintain
  * Retired "configure" file from source code package due to
    autoconf/automake versio conflicts, so that it is from now on to
    be generated by invoking "boostrap" script that uses locally
    available toolchain version for generating the "configure" file
  * Resolved namespace/label naming conflicts with other libraries by
    replacing global labels such as INTEGER_SAMPLES with more
    specific SOUNDTOUCH_INTEGER_SAMPLES etc.
  * Updated windows build scripts & project files for Visual Studio
    2008 support
  * Updated SoundTouch.dll API for .NET compatibility
  * Added API for querying nominal processing input & output sample
    batch sizes
* Thu Apr 14 2011 toddrme2178@gmail.com
- added 32bit compatibility libraries
* Thu Dec  9 2010 davejplater@gmail.com
- Update to version 1.5.0, added manpage for sounstrech
- Upstream changes :
  * Added normalization to correlation calculation and improvement
  automatic seek/sequence parameter calculation to improve sound
  quality
  * Fixes in compilation scripts for non-Intel platforms
  * Added Dynamic-Link-Library (DLL) version of SoundTouch library
  build, provided with Delphi/Pascal wrapper for calling the dll
  routines
  * Added #define PREVENT_CLICK_AT_RATE_CROSSOVER that prevents a
  click artifact when crossing the nominal pitch from either
  positive to negative side or vice versa
  * Other minor fixes & code cleanup
- Bugfixes :
  * Fixed negative array indexing in quick seek algorithm
  * FIR autoalias filter running too far in processing buffer
  * Check against zero sample count in rate transposing
  * Fix for x86-64 support: Removed pop/push instructions from the
  cpu detection algorithm.
  * Check against empty buffers in FIFOSampleBuffer
* Thu Dec  9 2010 davejplater@gmail.com
- Fixed rpmlint warnings and error.
* Thu Dec  9 2010 rguenther@novell.com
- drop bogus libstdc++ BuildRequires
* Thu Oct  1 2009 lnussel@suse.de
- fix library package to not depend on main package and glibc-devel
* Thu May  7 2009 sbrabec@suse.cz
- Updated to version 1.4.0:
  * Improved sound quality by automatic calculation of time stretch
    algorithm processing parameters according to tempo setting
  * Moved BPM detection routines from SoundStretch application into
    SoundTouch library
  * Bugfixes: Usage of uninitialied variables, GNU build scripts,
    compiler errors due to 'const' keyword mismatch.
  * Source code cleanup
- Split according to shared library packaging policy.
* Sat Apr  4 2009 crrodriguez@suse.de
- use --enable-shared and disable static libraries
* Thu Nov 22 2007 tiwai@suse.de
- fix build with gcc 4.3
* Wed Jul  4 2007 tiwai@suse.de
- fix build with the recent gcc
- fix build on architectures without SSE
- fix Makefile.am and removed hacks for autoreconf in spec file
* Thu Jun 21 2007 sbrabec@suse.cz
- New SuSE package, version 1.3.1.
